@@ -329,15 +329,15 @@ class EventsRuleToSqsProps:
         :summary: The properties for the EventsRuleToSqs Construct
         '''
         if isinstance(event_rule_props, dict):
-            event_rule_props = RuleProps(**event_rule_props)
+            event_rule_props = aws_cdk.aws_events.RuleProps(**event_rule_props)
         if isinstance(dead_letter_queue_props, dict):
-            dead_letter_queue_props = QueueProps(**dead_letter_queue_props)
+            dead_letter_queue_props = aws_cdk.aws_sqs.QueueProps(**dead_letter_queue_props)
         if isinstance(encryption_key_props, dict):
-            encryption_key_props = KeyProps(**encryption_key_props)
+            encryption_key_props = aws_cdk.aws_kms.KeyProps(**encryption_key_props)
         if isinstance(event_bus_props, dict):
-            event_bus_props = EventBusProps(**event_bus_props)
+            event_bus_props = aws_cdk.aws_events.EventBusProps(**event_bus_props)
         if isinstance(queue_props, dict):
-            queue_props = QueueProps(**queue_props)
+            queue_props = aws_cdk.aws_sqs.QueueProps(**queue_props)
         if __debug__:
             type_hints = typing.get_type_hints(EventsRuleToSqsProps.__init__)
             check_type(argname="argument event_rule_props", value=event_rule_props, expected_type=type_hints["event_rule_props"])
